# (ARt1nesE ^+slime 7raN5lA7OR ++💯-

To-_XO TR4NSlaT3 !++~ 4-slatt+_ me554g3, *XO 2Un ^*💔 mA1n.P`/ _!!_ aND-+forever+ PaSS _woah_ 5TR1n9-+_100 as _!!\*-4n ok+^ 4RgumEn7 !ok🦋!

1. In5tA|L !slatt+!-pac|<AGe-^\*💔

```shell
pip install cartinize
```

2. ImPo2t _ayy_+ mO)µLE +!!-

```python
from cartinize import carti
print(carti("Hello world")) # h3L|o !fye   wo2|D  !~slime-
```

_7акЖ3 ^Lit*+ ПоЗbОлЯЕт-*xo! n3pевОДИт +vampire+ рycсКnй 💫!+ н4 +💀 yaЗyk +👹+ кАР7n-+ok_
